from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import String, Boolean, Int, File

Rsat_Retrieve_Seq_V0_1_0 = CommandToolBuilder(tool="rsat_retrieve_seq", base_command=["rsat", "retrieve-seq"], inputs=[ToolInput(tag="in_org", input_type=String(optional=True), prefix="-org", doc=InputDocumentation(doc="When an organism is specified, the program automatically\nloads the appropriate genome sequence and feature table.\nIf this option is not used, the option -seq must be used\ninstead.\n(type supported-organism to obtain the list of supported\norganisms)")), ToolInput(tag="in_seq", input_type=Boolean(optional=True), prefix="-seq", doc=InputDocumentation(doc="input sequence file\n(alternative to organism)\nSpecify the input sequence file. See INPUT FORMAT\nbelow.")), ToolInput(tag="in_in_format", input_type=Boolean(optional=True), prefix="-informat", doc=InputDocumentation(doc="input sequence format")), ToolInput(tag="in_prefix", input_type=Boolean(optional=True), prefix="-prefix", doc=InputDocumentation(doc="prefix for sequence identifier")), ToolInput(tag="in_feat_type", input_type=Boolean(optional=True), prefix="-feattype", doc=InputDocumentation(doc="Feature type.\nSupported: gene,mRNA,tRNA,rRNA,scRNA,misc_RNA,CDS,start_codon,stop_codon,exon")), ToolInput(tag="in_type", input_type=Boolean(optional=True), prefix="-type", doc=InputDocumentation(doc="sequence type\nCurrently supported sequence types\nupstream (default)\ndownstream\norf (warning: introns are not spliced out)\nrandom (random fragments)\nTo implement in the future\nintrons\ncoding\nThe sub-option\n-type random\nrequires to use the -n for specifying the number of sequences.")), ToolInput(tag="in_sequecnes_only_type", input_type=Int(optional=True), prefix="-n", doc=InputDocumentation(doc="of sequecnes (only with -type random)")), ToolInput(tag="in_query_be_eg", input_type=String(optional=True), prefix="-q", doc=InputDocumentation(doc="The query should be an orf identifier (eg 'metR').\nThe query is case-insensitive.\nMultiple queries can be entered by reiteratively using the -q\noption.")), ToolInput(tag="in_query_file_taken", input_type=Boolean(optional=True), prefix="-i", doc=InputDocumentation(doc="query file. The first word of each line is taken as a query.\nThis option is incompatible with -q.")), ToolInput(tag="in_ids_only", input_type=Boolean(optional=True), prefix="-ids_only", doc=InputDocumentation(doc="Use this option if the queries are provided as a list\nof IDs. This avoids to load the table of synonyms, in\norder tos ave time.")), ToolInput(tag="in_all", input_type=Boolean(optional=True), prefix="-all", doc=InputDocumentation(doc="return all genomic upstream regions")), ToolInput(tag="in_name_output_file", input_type=File(optional=True), prefix="-o", doc=InputDocumentation(doc="name of the output file")), ToolInput(tag="in_oft", input_type=File(optional=True), prefix="-oft", doc=InputDocumentation(doc="output features file\nin addition to the sequences, export a feature file with the\nchromosomal location of the retrieved sequences.")), ToolInput(tag="in_from", input_type=Boolean(optional=True), prefix="-from", doc=InputDocumentation(doc="#1 -to #2\nwhere #1 and #2 are numbers. #2 should be higher than #1.\nlimits of the region to extract, relative to orf start\n(=position 0). Use negative values for upstream sequence.\nexample: -from -800 -to -1\nwill extract the 800 bp upstream the orf start.\n(this is the default)")), ToolInput(tag="in_format", input_type=String(optional=True), prefix="-format", doc=InputDocumentation(doc="to select different output formats, with the following\noptions:\nIG      IntelliGenetics (default format)\nWC      wconsensus format\nraw     only the sequence is returned, without spaces, newlines\nnor comments.\nFastA")), ToolInput(tag="in_lw", input_type=Boolean(optional=True), prefix="-lw", doc=InputDocumentation(doc="##  Line width. A newline character will be inserted in the\nsequence every ## bases. Default is 60.\n-lw 0 will prevent newline insertion.")), ToolInput(tag="in_label", input_type=String(optional=True), prefix="-label", doc=InputDocumentation(doc="Field(s) to be used in the sequence label.\nDefault: name.\nSupported: id,name,query,organism_name,sequence_type,current_from,current_to,ctg,orf_strand,reg_left,reg_right\nMultiple fields can be specified, separated by commas\nin the command line.\nExample:\n-label org,name,id\nIn this case, the sequence identifier will contain all\nof these fields, separated by the separator specified\nwith the option -labelsep.")), ToolInput(tag="in_labelsep", input_type=Boolean(optional=True), prefix="-labelsep", doc=InputDocumentation(doc="Separator between label fields. Default: |")), ToolInput(tag="in_no_orf", input_type=Boolean(optional=True), prefix="-noorf", doc=InputDocumentation(doc="prevent overlap with neighbout genes.\nWhen this option is active, the sequence size is\nadapted to avoid including coding sequences of the\nneighbour genes.\nThe reason for preventing overlap with upstream genes\nis that (at least for microbial organisms, and in\nlarge part for higher eukaryotes) most cis-acting\nelements are located in the non-coding regions. Thus,\nif the neighbour gene is closer than the selected\nlimit for collecting upstream sequences, the part of\ncoding sequences included it the result is likely to\nadd up to the noise, without bringing any additional\nsignal.\nMore importantly, coding and non-coding sequences\ngenerally have very different background models. The\ninclusion of coding sequences from neighbour genes may\nthus lead to biases in motif discovery.\nThe weaknesses of using this option are that, in some\ncases, predicted orf do not correspond to real genes,\nThis was particularly frequent in the early versions\nof the yeast genome, but the annotations have been\nimproved since then.\nFor bacterial sequences, it is essential to prevent\noverlap with upstream genes, because intergenic\ndistances are often very short, especially between\npairs of genes comprised in the same operon.")), ToolInput(tag="in_rm", input_type=Boolean(optional=True), prefix="-rm", doc=InputDocumentation(doc="Use the repeat masked version of the genome.  Attention :\nrepeated regions are annotated for some genomes only.")), ToolInput(tag="in_nocom", input_type=Boolean(optional=True), prefix="-nocom", doc=InputDocumentation(doc="no comments. Only the identifier and the sequence are\nreturned. By default, the comment indicates the ORF and\nupstream sequence coordinates.")), ToolInput(tag="in_imp_pos", input_type=Boolean(optional=True), prefix="-imp_pos", doc=InputDocumentation(doc="Admit imprecise positions.\nIn the annotation of some genomes, the limits of some genes\nare imprecisely specified (e.g. <555245, >898098). By default,\nthese genes are not loaded. The option -imp_pos allows to\nretrieve sequence for these genes as well, using the imprecise\ncoordinate as reference position.")), ToolInput(tag="in_nowarn", input_type=Boolean(optional=True), prefix="-nowarn", doc=InputDocumentation(doc="Prevents warning when a gene cannot be identified.")), ToolInput(tag="in_rand_sels", input_type=Boolean(optional=True), prefix="-randsels", doc=InputDocumentation(doc="#\nSelect a random set of # genes in the genome annotations.\nThis option ois obsolete, it has been replaced by a\nseparate command: random-genes. The option is\nmaintained for backward compatibility.")), ToolInput(tag="in_lf", input_type=Boolean(optional=True), prefix="-lf", doc=InputDocumentation(doc="length file\n(only with the option '-type random')\nAllows to generate random sequences with the same\nlengths as a set of reference sequences. The sequence\nlength file can be obtained with the command\nsequence-lengths\nThe length file contains two columns :\n- sequence ID (ignored)\n- sequence length")), ToolInput(tag="in_features", input_type=Boolean(optional=True), prefix="-features", doc=InputDocumentation(doc="alternate feature table. This option allows to speify\nan alternate file where the ORF locations are found.\nSee below for a description of the feature file format.")), ToolInput(tag="in_genes_dot", input_type=String(), position=0, doc=InputDocumentation(doc="CATEGORY")), ToolInput(tag="in_genomics", input_type=String(), position=1, doc=InputDocumentation(doc="sequences")), ToolInput(tag="in_column", input_type=String(), position=0, doc=InputDocumentation(doc="field   description"))], outputs=[ToolOutput(tag="out_name_output_file", output_type=File(optional=True), selector=InputSelector(input_to_select="in_name_output_file", type_hint=File()), doc=OutputDocumentation(doc="name of the output file")), ToolOutput(tag="out_oft", output_type=File(optional=True), selector=InputSelector(input_to_select="in_oft", type_hint=File()), doc=OutputDocumentation(doc="output features file\nin addition to the sequences, export a feature file with the\nchromosomal location of the retrieved sequences."))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Rsat_Retrieve_Seq_V0_1_0().translate("wdl", allow_empty_container=True)

